/*
 * This is part of the doxml library.  It declares an extension to the
 *  URI handler facility (declared in <doxml/uri.h>), a way of creating
 *  URI handlers which aggregate the results of other URI handlers.
 *  This way, if your application has 17 URI handlers and opens XML
 *  documents in 23 different places, rather than calling
 *  doxml_register_uri_handler() 221 different times, you can create
 *  a compound URI handler and just register it once with each
 *  doxml_context.
 *
 * Copyright (C) 1999 John Stracke, http://www.thibault.org
 *
 * This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Log: polyuri.h,v $
 * Revision 1.2  1999/06/25 21:17:37  francis
 * Changing DOXML_XML to DOXML_XML; adding idents
 *
 * Revision 1.1  1999/06/25 21:15:00  francis
 * Adding a framework for the application to provide doxml with URI
 * handlers for use in processing external IDs.  (Not providing URI
 * code as part of doxml means we can work with whatever URI code the
 * app wants, and don't have to write anything non-portable.)
 *
 * Also, changing old _LIBXML_ stuff in the headers to _DOXML_.
 *
 */

#ifndef _DOXML_DOXML_POLYURI_H_
#define _DOXML_DOXML_POLYURI_H_

#include <doxml/uri.h>

static const char* _doxml_version_ident_doxml_polyuri_h="$Id: polyuri.h,v 1.2 1999/06/25 21:17:37 francis Exp $";

struct doxml_compound_uri_handler_tag;
typedef struct doxml_compound_uri_handler_tag doxml_compound_uri_handler;

doxml_compound_uri_handler* doxml_create_compound_uri_handler(void);
void doxml_destroy_compound_uri_handler(doxml_compound_uri_handler* compound);

/* Registers the handler with compound.  Acts just like
 *  doxml_register_uri_handler() (see <doxml/uri.h>).  The
 *  doxml_uri_handler_ref returned can be unregistered with
 *  doxml_unregister_uri_handler().
 */
doxml_uri_handler_ref*
doxml_register_uri_handler_with_compound(doxml_compound_uri_handler* compound,
                                         doxml_uri_handler handler,
                                         void* handler_context);

/* The handler function for compounder handlers.  To register a compounder
 *  handler, pass this function as handler and the compound handler thunk
 *  (returned from doxml_create_compound_uri_handler(), above) as
 *  handler_context.
 */
const char* doxml_compound_uri_handler_handler(doxml_context* context,
                                               void* handler_context,
                                               const char* uri,
                                               doxml_uri_error* error);

#endif /*_DOXML_DOXML_POLYURI_H_*/
