/*
 * This is part of the doxml library, a parser for XML.  It should not
 *  require any functionality not defined in ANSI C's standard libraries.
 *
 * This module implements doxml_compound_uri_handler_handler().
 *
 * Copyright (C) 1999 John Stracke, http://www.thibault.org
 *
 * This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Log: polyuri.c,v $
 * Revision 1.1  1999/06/25 21:15:01  francis
 * Adding a framework for the application to provide doxml with URI
 * handlers for use in processing external IDs.  (Not providing URI
 * code as part of doxml means we can work with whatever URI code the
 * app wants, and don't have to write anything non-portable.)
 *
 * Also, changing old _LIBXML_ stuff in the headers to _DOXML_.
 *
 */

static const char* id="$Id: polyuri.c,v 1.1 1999/06/25 21:15:01 francis Exp $";

#include <doxml/uripriv.h>

const char*
doxml_compound_uri_handler_handler(doxml_context* context,
                                   void* handler_context,
                                   const char* uri,
                                   doxml_uri_error* error)
{
  doxml_compound_uri_handler* compound
    =(doxml_compound_uri_handler*)handler_context;
  if (!error)
    {
      /* Want to permit use even if the caller doesn't let us report errors */
      static doxml_uri_error error_bit_bucket;
      error=&error_bit_bucket;
    }

  if (!compound)
    {
      fprintf(stderr,"doxml_compound_uri_handler_handler(): NULL compound\n");
      (*error)=doxml_uri_error_internal;
      return 0;
    }

  if (!uri)
    {
      fprintf(stderr,"doxml_compound_uri_handler_handler(): NULL uri\n");
      (*error)=doxml_uri_error_internal;
      return 0;
    }

  {
    doxml_uri_handler_ref* cur;
    for (cur=compound->first; cur; cur=cur->next)
      {
        const char* res=(cur->handler)(context,
                                       cur->handler_context,
                                       uri,
                                       error);
        if (res)
          return res;

        if ((*error)==doxml_uri_error_unsupported_scheme)
          continue;
        
        if ((*error)==doxml_uri_error_none) /* obviously wrong */
          (*error)=doxml_uri_error_unknown;
        return 0;
      }
  }

  (*error)=doxml_uri_error_unsupported_scheme;
  return 0;
}
