/*
 * This is part of the doxml library, a parser for XML.  It should not
 *  require any functionality not defined in ANSI C's standard libraries.
 *
 * Copyright (C) 1999 John Stracke, http://www.thibault.org
 *
 * This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Log: setattr.c,v $
 * Revision 1.2  1999/07/24 16:55:28  francis
 * Adding support for entity-valued attributes
 *
 * Revision 1.1  1999/06/01 01:51:14  francis
 * Adding functions to get/set/clear attributes.  Reorganzing the
 * to-do list.  Fixing a parser bug introduced I removed support for
 * attributes with no values at release 0.2.
 *
 */

static const char* id="$Id: setattr.c,v 1.2 1999/07/24 16:55:28 francis Exp $";

#include <doxml/priv.h>
#include <string.h>

int doxml_attr_set(doxml_atom* element,
                   const char* namespace,
                   const char* name,
                   const char* value)
{
  doxml_attribute* attr=doxml_attr_seek(element,namespace,name);
  if (!attr)
    {
      if (!value)
        return 0;

      attr=doxml_attr_add(element,namespace,name,value);
      if (attr)
        return 0;
    }

  if (!value)
    {
      doxml_attr_del(element,attr);
      return 0;
    }

  {
    const char* newValue=strdup(value);
    if (!newValue)
      {
        fprintf(stderr,"doxml_attr_set(): cannot copy value: strdup() failed\n");
        return -1;
      }
    if (!(attr->is_entity))
      {
        if (attr->value.literal)
          free(attr->value.literal);
      }
    attr->value.literal=newValue;
  }

  return 0;
}

int doxml_attr_clear(doxml_atom* element,
                     const char* namespace,
                     const char* name)
{
  return doxml_attr_set(element,namespace,name,0);
}
