/*
 * This is part of the doxml library, a parser for XML.  It should not
 *  require any functionality not defined in ANSI C's standard libraries.
 *
 * Copyright (C) 1999 John Stracke
 *
 * This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Log: tstParseFile.c,v $
 * Revision 1.7  1999/07/24 22:41:04  francis
 * Pseudo-fixing a memory corruption problem, at the cost of memory leaks
 *
 * Revision 1.6  1999/07/19 01:32:48  francis
 * Not printing comments at top, so that output can be reparsed
 *
 * Revision 1.5  1999/06/20 16:30:14  francis
 * Adding partial support for <!DOCTYPE>.  It now handles doctypes with
 * names (all doctypes have names), with external-ids, but not with
 * any of the declarations.
 *
 * Revision 1.4  1999/06/07 04:57:38  francis
 * Implementing processing instructions.  Note the API changes.
 *
 * Revision 1.3  1999/05/21 23:05:43  francis
 * Finished renaming to doxml
 *
 * Revision 1.2  1999/05/21 22:59:49  francis
 * Partially renaming to doxml
 *
 * Revision 1.1.1.1  1999/05/21 22:20:37  francis
 * Initial checkin of libxml, to be renamed doxml
 *
 */

static const char* id="$Id: tstParseFile.c,v 1.7 1999/07/24 22:41:04 francis Exp $";

#include <doxml/priv.h>

#include <doxml/xml.h>

int main(int argc, const char* argv[])
{
  doxml_context* context;
  doxml_document* document;
  const char* filename=argv[1];
  if (!filename)
    filename="tst.xml";

  context=doxml_open_file(filename);
  if (!context)
    {
      fprintf(stderr,"%s: could not open file %s\n",
              argv[0],filename
              );
      return 2;
    }

  document=doxml_parse(context);
  if (!document)
    {
      fprintf(stderr,"%s: could not parse\n",argv[0]);
      return 3;
    }

#if 0
  if (document->xml_decl.version)
    printf("document->xml_decl.version==%s\n",document->xml_decl.version);
  if (document->xml_decl.encoding)
    printf("document->xml_decl.encoding==%s\n",document->xml_decl.encoding);
  if ((document->xml_decl.standalone)>=0)
    printf("document->xml_decl.standalone==%s\n",
           (document->xml_decl.standalone ? "yes" : "no")
           );

  if (   (document->xml_decl.version)
      || (document->xml_decl.encoding)
      || ((document->xml_decl.standalone)>=0)
      )
    printf("\n");
#endif

  if (doxml_write_document(stdout,document)<0)
    {
      fprintf(stderr,"%s: could not print XML\n",argv[0]);
      return 4;
    }

  doxml_delete_document(document);

  return 0;
}
